@@ -30,6 +30,9 @@ enum {
   TEXT_CARET_MOVED,
   TEXT_SELECTION_CHANGED,
   TEXT_ATTRIBUTES_CHANGED,
+  TEXT_INSERT,
+  TEXT_REMOVE,
+  TEXT_UPDATE,
   LAST_SIGNAL
 };
 
@@ -168,7 +171,37 @@ atk_text_base_init (AtkTextIface *class)
 		      atk_marshal_VOID__INT_INT,
 		      G_TYPE_NONE,
 		      2, G_TYPE_INT, G_TYPE_INT);
-      
+
+      atk_text_signals[TEXT_INSERT] =
+	g_signal_new ("text_insert",
+		      ATK_TYPE_TEXT,
+		      G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+		      0,
+		      (GSignalAccumulator) NULL, NULL,
+		      atk_marshal_VOID__INT_INT_STRING,
+		      G_TYPE_NONE,
+		      3, G_TYPE_INT, G_TYPE_INT, G_TYPE_STRING);
+
+      atk_text_signals[TEXT_REMOVE] =
+	g_signal_new ("text_remove",
+		      ATK_TYPE_TEXT,
+		      G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+		      0,
+		      (GSignalAccumulator) NULL, NULL,
+		      atk_marshal_VOID__INT_INT_STRING,
+		      G_TYPE_NONE,
+		      3, G_TYPE_INT, G_TYPE_INT, G_TYPE_STRING);
+
+      atk_text_signals[TEXT_UPDATE] =
+	g_signal_new ("text_update",
+		      ATK_TYPE_TEXT,
+		      G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+		      0,
+		      (GSignalAccumulator) NULL, NULL,
+		      atk_marshal_VOID__INT_INT_INT_STRING,
+		      G_TYPE_NONE,
+		      4, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_STRING);
+
       atk_text_signals[TEXT_CARET_MOVED] =
 	g_signal_new ("text_caret_moved",
 		      ATK_TYPE_TEXT,
@@ -966,7 +999,7 @@ atk_text_get_range_extents (AtkText          *text,
 /**
  * atk_text_get_bounded_ranges:
  * @text: an #AtkText
- * @rect: An AtkTextRectagle giving the dimensions of the bounding box.
+ * @rect: An AtkTextRectangle giving the dimensions of the bounding box.
  * @coord_type: Specify whether coordinates are relative to the screen or widget window.
  * @x_clip_type: Specify the horizontal clip type.
  * @y_clip_type: Specify the vertical clip type.
@@ -975,8 +1008,8 @@ atk_text_get_range_extents (AtkText          *text,
  *
  * Since: 1.3
  *
- * Returns: Array of AtkTextRange. The last element of the array returned 
- *          by this function will be NULL.
+ * Returns: (array zero-terminated=1): Array of AtkTextRange. The last
+ *          element of the array returned by this function will be NULL.
  **/
 AtkTextRange**
 atk_text_get_bounded_ranges (AtkText          *text,
@@ -1365,10 +1398,32 @@ atk_text_free_ranges (AtkTextRange **ranges)
           AtkTextRange *range;
 
           range = *ranges;
-          *ranges++;
+          ranges++;
           g_free (range->content);
           g_free (range);
         }
       g_free (first);
     }
 }
+
+static AtkTextRange *
+atk_text_range_copy (AtkTextRange *src)
+{
+  AtkTextRange *dst = g_new0 (AtkTextRange, 1);
+  dst->bounds = src->bounds;
+  dst->start_offset = src->start_offset;
+  dst->end_offset = src->end_offset;
+  if (src->content)
+    dst->content = g_strdup (src->content);
+  return dst;
+}
+
+static void
+atk_text_range_free (AtkTextRange *range)
+{
+  g_free (range->content);
+  g_free (range);
+}
+
+G_DEFINE_BOXED_TYPE (AtkTextRange, atk_text_range, atk_text_range_copy,
+                     atk_text_range_free)
