@@ -19,6 +19,7 @@
 
 #include "atkutil.h"
 #include "atkmarshal.c"
+#include "config.h"
 
 static void atk_util_class_init (AtkUtilClass *klass);
 
@@ -226,7 +227,7 @@ atk_add_global_event_listener (GSignalEmissionHook listener,
     }
   else
     {
-      retval = -1;
+      retval = 0;
     }
   g_type_class_unref (klass);
 
@@ -271,7 +272,7 @@ atk_add_key_event_listener (AtkKeySnoopFunc listener, gpointer data)
     }
   else
     {
-      retval = -1;
+      retval = 0;
     }
 
   return retval;
@@ -297,7 +298,8 @@ atk_remove_key_event_listener (guint listener_id)
  *
  * Gets the root accessible container for the current application.
  *
- * Returns: the root accessible container for the current application
+ * Returns: (transfer none): the root accessible container for the current
+ * application
  **/
 AtkObject*
 atk_get_root (void)
@@ -322,9 +324,10 @@ atk_get_root (void)
  *
  * Gets the currently focused object.
  * 
- * Since: ATK 1.6
+ * Since: 1.6
  *
- * Returns: the currently focused object for the current application
+ * Returns: (transfer none): the currently focused object for the current
+ * application
  **/
 AtkObject*
 atk_get_focus_object (void)
@@ -381,3 +384,19 @@ atk_get_toolkit_version (void)
 
   return retval;
 }
+
+/**
+ * atk_get_version:
+ *
+ * Gets the current version for ATK.
+ *
+ * Returns: version string for ATK
+ *
+ * Since: 1.20
+ */
+G_CONST_RETURN gchar *
+atk_get_version (void)
+{
+  return VERSION;
+}
+
